@@ -16,6 +16,8 @@
 #include <sys/wait.h>
 #include <libosso.h>
 
+#include "mad-developer.h"
+
 #define null ((void*)0)
 #define true (1)
 
@@ -31,7 +33,7 @@ static void exec_child(void)
     setregid(gid, gid);
 
     execl("/bin/su", "su", "-", "developer", "-c",
-	  "cd /usr/lib/mad-developer; exec ./mad-withhome.sh ./mad-developer",
+	  "cd " LIBDIR "; exec ./mad-withhome.sh ./mad-developer",
 	  (void *)0);
     exit(1);
 }
